DiCodes

Struct DiCodes 

pub struct DiCodes { /* private fields */ }
Decoder identification and Dynamic PTY indicator / DI codes See the RDS Standard section 3.2.1.5.

Implementations

Source

impl DiCodes

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl DiCodes

pub const fn into_bytes(self) -> [u8; 1]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 1]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl DiCodes

pub fn dynamic_pty(&self) -> <bool as Specifier>::InOut

Returns the value of dynamic_pty.

pub fn dynamic_pty_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of dynamic_pty.

#Errors

If the returned value contains an invalid bit pattern for dynamic_pty.

pub fn with_dynamic_pty(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of dynamic_pty set to the given value.

#Panics

If the given value is out of bounds for dynamic_pty.

pub fn with_dynamic_pty_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of dynamic_pty set to the given value.

#Errors

If the given value is out of bounds for dynamic_pty.

pub fn set_dynamic_pty(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of dynamic_pty to the given value.

#Panics

If the given value is out of bounds for dynamic_pty.

pub fn set_dynamic_pty_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of dynamic_pty to the given value.

#Errors

If the given value is out of bounds for dynamic_pty.

pub fn compressed(&self) -> <bool as Specifier>::InOut

Returns the value of compressed.

pub fn compressed_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of compressed.

#Errors

If the returned value contains an invalid bit pattern for compressed.

pub fn with_compressed(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of compressed set to the given value.

#Panics

If the given value is out of bounds for compressed.

pub fn with_compressed_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of compressed set to the given value.

#Errors

If the given value is out of bounds for compressed.

pub fn set_compressed(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of compressed to the given value.

#Panics

If the given value is out of bounds for compressed.

pub fn set_compressed_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of compressed to the given value.

#Errors

If the given value is out of bounds for compressed.

pub fn artificial_head(&self) -> <bool as Specifier>::InOut

Returns the value of artificial_head.

pub fn artificial_head_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of artificial_head.

#Errors

If the returned value contains an invalid bit pattern for artificial_head.

pub fn with_artificial_head(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of artificial_head set to the given value.

#Panics

If the given value is out of bounds for artificial_head.

pub fn with_artificial_head_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of artificial_head set to the given value.

#Errors

If the given value is out of bounds for artificial_head.

pub fn set_artificial_head(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of artificial_head to the given value.

#Panics

If the given value is out of bounds for artificial_head.

pub fn set_artificial_head_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of artificial_head to the given value.

#Errors

If the given value is out of bounds for artificial_head.

pub fn stereo(&self) -> <bool as Specifier>::InOut

Returns the value of stereo.

pub fn stereo_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of stereo.

#Errors

If the returned value contains an invalid bit pattern for stereo.

pub fn with_stereo(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of stereo set to the given value.

#Panics

If the given value is out of bounds for stereo.

pub fn with_stereo_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of stereo set to the given value.

#Errors

If the given value is out of bounds for stereo.

pub fn set_stereo(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of stereo to the given value.

#Panics

If the given value is out of bounds for stereo.

pub fn set_stereo_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of stereo to the given value.

#Errors

If the given value is out of bounds for stereo.