Group

Struct Group 

pub struct Group {
    pub a: Option<u16>,
    pub b: Option<u16>,
    pub c: Option<u16>,
    pub d: Option<u16>,
}
An RDS group, when transmitted, is a 104 bit item consisting of 4 blocks (A, B, C, D). Each block consists of 26 bits: a 16 data information word followed by a 10 bit checkword. The receiver strips the 10 bit checkword, and evaluates it to determine if the the block should be passed along for decoding.

See the RDS Standard section 2.1.

Fields

a: Option<u16>b: Option<u16>c: Option<u16>d: Option<u16>