pub struct GroupType { /* private fields */ }Expand description
Group type code and version. See the RDS Standard section 3.1.3 - Table 3.
Implementations
Sourceimpl GroupType
impl GroupType
Sourcepub const fn into_bytes(self) -> [u8; 1]
pub const fn into_bytes(self) -> [u8; 1]
Sourcepub const fn from_bytes(bytes: [u8; 1]) -> Self
pub const fn from_bytes(bytes: [u8; 1]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl GroupType
impl GroupType
Sourcepub fn code_or_err(
&self,
) -> Result<<B4 as Specifier>::InOut, InvalidBitPattern<<B4 as Specifier>::Bytes>>
pub fn code_or_err( &self, ) -> Result<<B4 as Specifier>::InOut, InvalidBitPattern<<B4 as Specifier>::Bytes>>
Returns the value of code.
#Errors
If the returned value contains an invalid bit pattern for code.
Sourcepub fn version_or_err(
&self,
) -> Result<<GroupVersion as Specifier>::InOut, InvalidBitPattern<<GroupVersion as Specifier>::Bytes>>
pub fn version_or_err( &self, ) -> Result<<GroupVersion as Specifier>::InOut, InvalidBitPattern<<GroupVersion as Specifier>::Bytes>>
Returns the value of version.
#Errors
If the returned value contains an invalid bit pattern for version.