ValidFields

Struct ValidFields 

pub struct ValidFields { /* private fields */ }
Bitflags indicating the RDS fields that are valid / have been received and decoded.

Implementations

Source

impl ValidFields

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl ValidFields

pub const fn into_bytes(self) -> [u8; 3]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 3]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl ValidFields

pub fn af(&self) -> <bool as Specifier>::InOut

Returns the value of af. Alternative Frequency (AF) data for the tuned network.

pub fn af_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of af.

#Errors

If the returned value contains an invalid bit pattern for af. Alternative Frequency (AF) data for the tuned network.

pub fn with_af(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of af set to the given value.

#Panics

If the given value is out of bounds for af. Alternative Frequency (AF) data for the tuned network.

pub fn with_af_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of af set to the given value.

#Errors

If the given value is out of bounds for af. Alternative Frequency (AF) data for the tuned network.

pub fn set_af(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of af to the given value.

#Panics

If the given value is out of bounds for af. Alternative Frequency (AF) data for the tuned network.

pub fn set_af_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of af to the given value.

#Errors

If the given value is out of bounds for af. Alternative Frequency (AF) data for the tuned network.

pub fn on_freqs(&self) -> <bool as Specifier>::InOut

Returns the value of on_freqs. Alternative Freqnency data for the other network (ON).

pub fn on_freqs_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of on_freqs.

#Errors

If the returned value contains an invalid bit pattern for on_freqs. Alternative Freqnency data for the other network (ON).

pub fn with_on_freqs(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of on_freqs set to the given value.

#Panics

If the given value is out of bounds for on_freqs. Alternative Freqnency data for the other network (ON).

pub fn with_on_freqs_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of on_freqs set to the given value.

#Errors

If the given value is out of bounds for on_freqs. Alternative Freqnency data for the other network (ON).

pub fn set_on_freqs(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of on_freqs to the given value.

#Panics

If the given value is out of bounds for on_freqs. Alternative Freqnency data for the other network (ON).

pub fn set_on_freqs_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of on_freqs to the given value.

#Errors

If the given value is out of bounds for on_freqs. Alternative Freqnency data for the other network (ON).

pub fn map_freqs(&self) -> <bool as Specifier>::InOut

Returns the value of map_freqs. Mapped alternative frequency data for the other network.

pub fn map_freqs_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of map_freqs.

#Errors

If the returned value contains an invalid bit pattern for map_freqs. Mapped alternative frequency data for the other network.

pub fn with_map_freqs(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of map_freqs set to the given value.

#Panics

If the given value is out of bounds for map_freqs. Mapped alternative frequency data for the other network.

pub fn with_map_freqs_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of map_freqs set to the given value.

#Errors

If the given value is out of bounds for map_freqs. Mapped alternative frequency data for the other network.

pub fn set_map_freqs(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of map_freqs to the given value.

#Panics

If the given value is out of bounds for map_freqs. Mapped alternative frequency data for the other network.

pub fn set_map_freqs_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of map_freqs to the given value.

#Errors

If the given value is out of bounds for map_freqs. Mapped alternative frequency data for the other network.

pub fn clock(&self) -> <bool as Specifier>::InOut

Returns the value of clock. Clock data.

pub fn clock_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of clock.

#Errors

If the returned value contains an invalid bit pattern for clock. Clock data.

pub fn with_clock(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of clock set to the given value.

#Panics

If the given value is out of bounds for clock. Clock data.

pub fn with_clock_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of clock set to the given value.

#Errors

If the given value is out of bounds for clock. Clock data.

pub fn set_clock(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of clock to the given value.

#Panics

If the given value is out of bounds for clock. Clock data.

pub fn set_clock_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of clock to the given value.

#Errors

If the given value is out of bounds for clock. Clock data.

pub fn ews(&self) -> <bool as Specifier>::InOut

Returns the value of ews. Emergency Warning System (EWS).

pub fn ews_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of ews.

#Errors

If the returned value contains an invalid bit pattern for ews. Emergency Warning System (EWS).

pub fn with_ews(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of ews set to the given value.

#Panics

If the given value is out of bounds for ews. Emergency Warning System (EWS).

pub fn with_ews_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of ews set to the given value.

#Errors

If the given value is out of bounds for ews. Emergency Warning System (EWS).

pub fn set_ews(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of ews to the given value.

#Panics

If the given value is out of bounds for ews. Emergency Warning System (EWS).

pub fn set_ews_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of ews to the given value.

#Errors

If the given value is out of bounds for ews. Emergency Warning System (EWS).

pub fn pin(&self) -> <bool as Specifier>::InOut

Returns the value of pin. Program Item Number (PIN) for tuned network (TN).

pub fn pin_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of pin.

#Errors

If the returned value contains an invalid bit pattern for pin. Program Item Number (PIN) for tuned network (TN).

pub fn with_pin(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of pin set to the given value.

#Panics

If the given value is out of bounds for pin. Program Item Number (PIN) for tuned network (TN).

pub fn with_pin_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of pin set to the given value.

#Errors

If the given value is out of bounds for pin. Program Item Number (PIN) for tuned network (TN).

pub fn set_pin(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of pin to the given value.

#Panics

If the given value is out of bounds for pin. Program Item Number (PIN) for tuned network (TN).

pub fn set_pin_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of pin to the given value.

#Errors

If the given value is out of bounds for pin. Program Item Number (PIN) for tuned network (TN).

pub fn pin_on(&self) -> <bool as Specifier>::InOut

Returns the value of pin_on. Program Item Number (PIN) for other network (ON).

pub fn pin_on_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of pin_on.

#Errors

If the returned value contains an invalid bit pattern for pin_on. Program Item Number (PIN) for other network (ON).

pub fn with_pin_on(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of pin_on set to the given value.

#Panics

If the given value is out of bounds for pin_on. Program Item Number (PIN) for other network (ON).

pub fn with_pin_on_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of pin_on set to the given value.

#Errors

If the given value is out of bounds for pin_on. Program Item Number (PIN) for other network (ON).

pub fn set_pin_on(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of pin_on to the given value.

#Panics

If the given value is out of bounds for pin_on. Program Item Number (PIN) for other network (ON).

pub fn set_pin_on_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of pin_on to the given value.

#Errors

If the given value is out of bounds for pin_on. Program Item Number (PIN) for other network (ON).

pub fn pi(&self) -> <bool as Specifier>::InOut

Returns the value of pi. Program Identification (PI code).

pub fn pi_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of pi.

#Errors

If the returned value contains an invalid bit pattern for pi. Program Identification (PI code).

pub fn with_pi(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of pi set to the given value.

#Panics

If the given value is out of bounds for pi. Program Identification (PI code).

pub fn with_pi_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of pi set to the given value.

#Errors

If the given value is out of bounds for pi. Program Identification (PI code).

pub fn set_pi(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of pi to the given value.

#Panics

If the given value is out of bounds for pi. Program Identification (PI code).

pub fn set_pi_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of pi to the given value.

#Errors

If the given value is out of bounds for pi. Program Identification (PI code).

pub fn ps(&self) -> <bool as Specifier>::InOut

Returns the value of ps. Program service name (PS) for the tuned network (TN).

pub fn ps_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of ps.

#Errors

If the returned value contains an invalid bit pattern for ps. Program service name (PS) for the tuned network (TN).

pub fn with_ps(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of ps set to the given value.

#Panics

If the given value is out of bounds for ps. Program service name (PS) for the tuned network (TN).

pub fn with_ps_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of ps set to the given value.

#Errors

If the given value is out of bounds for ps. Program service name (PS) for the tuned network (TN).

pub fn set_ps(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of ps to the given value.

#Panics

If the given value is out of bounds for ps. Program service name (PS) for the tuned network (TN).

pub fn set_ps_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of ps to the given value.

#Errors

If the given value is out of bounds for ps. Program service name (PS) for the tuned network (TN).

pub fn ps_on(&self) -> <bool as Specifier>::InOut

Returns the value of ps_on. Program service name (PS) for the other network (ON).

pub fn ps_on_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of ps_on.

#Errors

If the returned value contains an invalid bit pattern for ps_on. Program service name (PS) for the other network (ON).

pub fn with_ps_on(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of ps_on set to the given value.

#Panics

If the given value is out of bounds for ps_on. Program service name (PS) for the other network (ON).

pub fn with_ps_on_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of ps_on set to the given value.

#Errors

If the given value is out of bounds for ps_on. Program service name (PS) for the other network (ON).

pub fn set_ps_on(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of ps_on to the given value.

#Panics

If the given value is out of bounds for ps_on. Program service name (PS) for the other network (ON).

pub fn set_ps_on_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of ps_on to the given value.

#Errors

If the given value is out of bounds for ps_on. Program service name (PS) for the other network (ON).

pub fn pty(&self) -> <bool as Specifier>::InOut

Returns the value of pty. Program type (PTY).

pub fn pty_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of pty.

#Errors

If the returned value contains an invalid bit pattern for pty. Program type (PTY).

pub fn with_pty(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of pty set to the given value.

#Panics

If the given value is out of bounds for pty. Program type (PTY).

pub fn with_pty_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of pty set to the given value.

#Errors

If the given value is out of bounds for pty. Program type (PTY).

pub fn set_pty(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of pty to the given value.

#Panics

If the given value is out of bounds for pty. Program type (PTY).

pub fn set_pty_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of pty to the given value.

#Errors

If the given value is out of bounds for pty. Program type (PTY).

pub fn ptyn(&self) -> <bool as Specifier>::InOut

Returns the value of ptyn. Program type name (PTYN).

pub fn ptyn_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of ptyn.

#Errors

If the returned value contains an invalid bit pattern for ptyn. Program type name (PTYN).

pub fn with_ptyn(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of ptyn set to the given value.

#Panics

If the given value is out of bounds for ptyn. Program type name (PTYN).

pub fn with_ptyn_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of ptyn set to the given value.

#Errors

If the given value is out of bounds for ptyn. Program type name (PTYN).

pub fn set_ptyn(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of ptyn to the given value.

#Panics

If the given value is out of bounds for ptyn. Program type name (PTYN).

pub fn set_ptyn_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of ptyn to the given value.

#Errors

If the given value is out of bounds for ptyn. Program type name (PTYN).

pub fn rt(&self) -> <bool as Specifier>::InOut

Returns the value of rt. Radiotext (RT).

pub fn rt_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of rt.

#Errors

If the returned value contains an invalid bit pattern for rt. Radiotext (RT).

pub fn with_rt(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of rt set to the given value.

#Panics

If the given value is out of bounds for rt. Radiotext (RT).

pub fn with_rt_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of rt set to the given value.

#Errors

If the given value is out of bounds for rt. Radiotext (RT).

pub fn set_rt(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of rt to the given value.

#Panics

If the given value is out of bounds for rt. Radiotext (RT).

pub fn set_rt_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of rt to the given value.

#Errors

If the given value is out of bounds for rt. Radiotext (RT).

pub fn slc(&self) -> <bool as Specifier>::InOut

Returns the value of slc. Service linked data. See RDSM spec. (3.2.1.8.3).

pub fn slc_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of slc.

#Errors

If the returned value contains an invalid bit pattern for slc. Service linked data. See RDSM spec. (3.2.1.8.3).

pub fn with_slc(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of slc set to the given value.

#Panics

If the given value is out of bounds for slc. Service linked data. See RDSM spec. (3.2.1.8.3).

pub fn with_slc_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of slc set to the given value.

#Errors

If the given value is out of bounds for slc. Service linked data. See RDSM spec. (3.2.1.8.3).

pub fn set_slc(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of slc to the given value.

#Panics

If the given value is out of bounds for slc. Service linked data. See RDSM spec. (3.2.1.8.3).

pub fn set_slc_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of slc to the given value.

#Errors

If the given value is out of bounds for slc. Service linked data. See RDSM spec. (3.2.1.8.3).

pub fn tdc(&self) -> <bool as Specifier>::InOut

Returns the value of tdc. Transparent data channel data.

pub fn tdc_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of tdc.

#Errors

If the returned value contains an invalid bit pattern for tdc. Transparent data channel data.

pub fn with_tdc(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of tdc set to the given value.

#Panics

If the given value is out of bounds for tdc. Transparent data channel data.

pub fn with_tdc_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of tdc set to the given value.

#Errors

If the given value is out of bounds for tdc. Transparent data channel data.

pub fn set_tdc(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of tdc to the given value.

#Panics

If the given value is out of bounds for tdc. Transparent data channel data.

pub fn set_tdc_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of tdc to the given value.

#Errors

If the given value is out of bounds for tdc. Transparent data channel data.

pub fn ta(&self) -> <bool as Specifier>::InOut

Returns the value of ta. Traffic Announcement (TA) for the tuned network (TN).

pub fn ta_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of ta.

#Errors

If the returned value contains an invalid bit pattern for ta. Traffic Announcement (TA) for the tuned network (TN).

pub fn with_ta(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of ta set to the given value.

#Panics

If the given value is out of bounds for ta. Traffic Announcement (TA) for the tuned network (TN).

pub fn with_ta_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of ta set to the given value.

#Errors

If the given value is out of bounds for ta. Traffic Announcement (TA) for the tuned network (TN).

pub fn set_ta(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of ta to the given value.

#Panics

If the given value is out of bounds for ta. Traffic Announcement (TA) for the tuned network (TN).

pub fn set_ta_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of ta to the given value.

#Errors

If the given value is out of bounds for ta. Traffic Announcement (TA) for the tuned network (TN).

pub fn ta_on(&self) -> <bool as Specifier>::InOut

Returns the value of ta_on. Traffic Announcement (TA) for the other network (ON).

pub fn ta_on_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of ta_on.

#Errors

If the returned value contains an invalid bit pattern for ta_on. Traffic Announcement (TA) for the other network (ON).

pub fn with_ta_on(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of ta_on set to the given value.

#Panics

If the given value is out of bounds for ta_on. Traffic Announcement (TA) for the other network (ON).

pub fn with_ta_on_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of ta_on set to the given value.

#Errors

If the given value is out of bounds for ta_on. Traffic Announcement (TA) for the other network (ON).

pub fn set_ta_on(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of ta_on to the given value.

#Panics

If the given value is out of bounds for ta_on. Traffic Announcement (TA) for the other network (ON).

pub fn set_ta_on_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of ta_on to the given value.

#Errors

If the given value is out of bounds for ta_on. Traffic Announcement (TA) for the other network (ON).

pub fn tp(&self) -> <bool as Specifier>::InOut

Returns the value of tp. Traffic Program (TP) for the tuned network (TN).

pub fn tp_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of tp.

#Errors

If the returned value contains an invalid bit pattern for tp. Traffic Program (TP) for the tuned network (TN).

pub fn with_tp(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of tp set to the given value.

#Panics

If the given value is out of bounds for tp. Traffic Program (TP) for the tuned network (TN).

pub fn with_tp_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of tp set to the given value.

#Errors

If the given value is out of bounds for tp. Traffic Program (TP) for the tuned network (TN).

pub fn set_tp(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of tp to the given value.

#Panics

If the given value is out of bounds for tp. Traffic Program (TP) for the tuned network (TN).

pub fn set_tp_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of tp to the given value.

#Errors

If the given value is out of bounds for tp. Traffic Program (TP) for the tuned network (TN).

pub fn tp_on(&self) -> <bool as Specifier>::InOut

Returns the value of tp_on. Traffic Program (TP) for the other network (ON).

pub fn tp_on_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of tp_on.

#Errors

If the returned value contains an invalid bit pattern for tp_on. Traffic Program (TP) for the other network (ON).

pub fn with_tp_on(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of tp_on set to the given value.

#Panics

If the given value is out of bounds for tp_on. Traffic Program (TP) for the other network (ON).

pub fn with_tp_on_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of tp_on set to the given value.

#Errors

If the given value is out of bounds for tp_on. Traffic Program (TP) for the other network (ON).

pub fn set_tp_on(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of tp_on to the given value.

#Panics

If the given value is out of bounds for tp_on. Traffic Program (TP) for the other network (ON).

pub fn set_tp_on_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of tp_on to the given value.

#Errors

If the given value is out of bounds for tp_on. Traffic Program (TP) for the other network (ON).

pub fn ms(&self) -> <bool as Specifier>::InOut

Returns the value of ms. Music/Speech flag. true=music.

pub fn ms_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of ms.

#Errors

If the returned value contains an invalid bit pattern for ms. Music/Speech flag. true=music.

pub fn with_ms(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of ms set to the given value.

#Panics

If the given value is out of bounds for ms. Music/Speech flag. true=music.

pub fn with_ms_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of ms set to the given value.

#Errors

If the given value is out of bounds for ms. Music/Speech flag. true=music.

pub fn set_ms(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of ms to the given value.

#Panics

If the given value is out of bounds for ms. Music/Speech flag. true=music.

pub fn set_ms_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of ms to the given value.

#Errors

If the given value is out of bounds for ms. Music/Speech flag. true=music.

pub fn eon(&self) -> <bool as Specifier>::InOut

Returns the value of eon. Enhanced other network (EON) data.

pub fn eon_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of eon.

#Errors

If the returned value contains an invalid bit pattern for eon. Enhanced other network (EON) data.

pub fn with_eon(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of eon set to the given value.

#Panics

If the given value is out of bounds for eon. Enhanced other network (EON) data.

pub fn with_eon_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of eon set to the given value.

#Errors

If the given value is out of bounds for eon. Enhanced other network (EON) data.

pub fn set_eon(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of eon to the given value.

#Panics

If the given value is out of bounds for eon. Enhanced other network (EON) data.

pub fn set_eon_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of eon to the given value.

#Errors

If the given value is out of bounds for eon. Enhanced other network (EON) data.