GroupType

Struct GroupType 

pub struct GroupType { /* private fields */ }
Group type code and version. See the RDS Standard section 3.1.3 - Table 3.

Implementations

Source

impl GroupType

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl GroupType

pub const fn into_bytes(self) -> [u8; 1]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 1]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl GroupType

pub fn code(&self) -> <B4 as Specifier>::InOut

Returns the value of code.

pub fn code_or_err( &self, ) -> Result<<B4 as Specifier>::InOut, InvalidBitPattern<<B4 as Specifier>::Bytes>>

Returns the value of code.

#Errors

If the returned value contains an invalid bit pattern for code.

pub fn version(&self) -> <GroupVersion as Specifier>::InOut

Returns the value of version.

pub fn version_or_err( &self, ) -> Result<<GroupVersion as Specifier>::InOut, InvalidBitPattern<<GroupVersion as Specifier>::Bytes>>

Returns the value of version.

#Errors

If the returned value contains an invalid bit pattern for version.