pub struct RdsData {Show 18 fields
pub program_information: ProgramInformation,
pub tn: NetworkInfo,
pub on: NetworkInfo,
pub content: Content,
pub rt: RtData,
pub clock: Clock,
pub slc: SlcData,
pub ptyn: PtynData,
pub oda: LinearMap<u16, OdaEntry, 10>,
pub tdc: TdcData,
pub ews: EwsData,
pub did_pty: DiCodes,
pub alt_freqs: AfTable,
pub alt_freq_decoder: AfDecoder,
pub on_freqs: AfTable,
pub on_freq_decoder: AfDecoder,
pub map_freqs: AfTable,
pub valid: ValidFields,
}Expand description
Container for all decoded RDS data.
This struct is populated by the Decoder, which is passed many blocks
of raw RDS data to decode. Depending what information is broadcast
and passed to the decoder, some of the fields in this struct will contain
valid data. The valid field is a bitmask that should be used first before
dereferencing any members of this struct.
Fields
program_information: ProgramInformationProgram Identification Code
tn: NetworkInfoTuned network (TN) info.
on: NetworkInfoOther network (ON) info.
content: ContentMusic/Speech flag.
rt: RtDataRadiotext
clock: ClockClock time
slc: SlcDataSlow labelling codes
ptyn: PtynDataProgram Type Name (extended PTY)
oda: LinearMap<u16, OdaEntry, 10>Active Open Data Applications
tdc: TdcDataTransparent Data Channels
ews: EwsDataEmergency Warning System
did_pty: DiCodesalt_freqs: AfTablealt_freq_decoder: AfDecoderon_freqs: AfTableon_freq_decoder: AfDecodermap_freqs: AfTablevalid: ValidFieldsBitmask of which fields are valid